@@ -34,7 +34,7 @@ class BaseAuthBackend(ABC):
             with shelve.open(self.config_path) as cfg:
                     self.token = cfg['token']
                     self.needs_validation = True
-                    print(f"Got config {self.token}")
+                    logger.debug("Found local config")
         except KeyError:
             self.token = None
             self.needs_validation = False
