@@ -7,6 +7,8 @@ from bergen.wards.base import BaseWard
 from bergen.postmans.base import BasePostman
 import logging
 from threading import Thread
+
+
 logger = logging.getLogger(__name__)
 import os
 
@@ -16,50 +18,56 @@ def start_background_loop(loop: asyncio.AbstractEventLoop) -> None:
 class BaseBergen:
 
 
-    def __init__(self, auth: BaseAuthBackend, host: str, port: int, protocol = "http", auto_negotiate=True, bind=True, log=logging.INFO, local=None, loop=None,  client_type: ClientType = None, jupyter=False, force_sync = False, **kwargs) -> None:
-        
-        self.running_in_sync = jupyter or force_sync
+    def __init__(self, auth: BaseAuthBackend= None, host: str = None, port: int = None, ssl=False, auto_negotiate=True, bind=True, log=logging.INFO, local=None, loop=None,  client_type: ClientType = None, jupyter=False, force_sync = False, **kwargs) -> None:
         
 
-        try:
-            self.loop = asyncio.get_running_loop()
-            if self.running_in_sync:
-                import nest_asyncio
-                nest_asyncio.apply(self.loop)
-
-        except RuntimeError:
-            self.loop = asyncio.get_event_loop()
-            self.loop_is_running = False
-            logger.info("Created New Eventloop")
-
-        if bind: 
-            # We only import this here for typehints
-            from bergen.registries.arnheim import set_current_arnheim
-            set_current_arnheim(self)
-
-
-        if log is not False:
+        if jupyter:
+            setLogging(logging.ERROR)
+        else:
             print(r"     _               _          _              ____ _ _            _    ")   
             print(r"    / \   _ __ _ __ | |__   ___(_)_ __ ___    / ___| (_) ___ _ __ | |_  ")
             print(r"   / _ \ | '__| '_ \| '_ \ / _ \ | '_ ` _ \  | |   | | |/ _ \ '_ \| __| ")
             print(r"  / ___ \| |  | | | | | | |  __/ | | | | | | | |___| | |  __/ | | | |_  ")
             print(r" /_/   \_\_|  |_| |_|_| |_|\___|_|_| |_| |_|  \____|_|_|\___|_| |_|\__| ")
             print(r"")
-            setLogging(True, log)
+            setLogging(log)
 
 
+        self.running_in_sync = force_sync
+        
+
+        
+        self.loop = asyncio.get_event_loop()
+        if self.loop.is_running():
+            if self.running_in_sync:
+                import nest_asyncio
+                nest_asyncio.apply(self.loop)
+            self.loop_is_running = True
+        else:
+            self.loop_is_running = False
+
+        if bind: 
+            # We only import this here for typehints
+            from bergen.registries.arnheim import set_current_arnheim
+            set_current_arnheim(self)
+
+        
+
         self.local = local if local is not None else os.getenv("ARNHEIM_LOCAL") == "1" 
+
         if self.local:
             logger.info("Running in Local Mode")
 
         self.client_type = client_type
+
+
         self.auth = auth
         self.token = self.auth.getToken()
         logger.info(" Auhorized!!!!!")
 
         self.host = host
         self.port = port
-        self.protocol = protocol
+        self.protocol = "https" if ssl else "http"
 
         self._transcript = None
         self.identifierDataPointMap = {}
@@ -175,7 +183,7 @@ class BaseBergen:
             <p> Arnheim Client <p>
             <table>
                 <tr>
-                    <td> Connected to </td> <td> {self.main_ward.host} </td>
+                    <td> Connected to </td> <td> {self.main_ward.name} </td>
                 </tr>
             </table>
 
@@ -183,9 +191,10 @@ class BaseBergen:
 
     async def __aenter__(self):
         await self.negotiate_async()
-        print(self)
+        return self
 
 
     async def __aexit__(self,*args, **kwargs):
         await self.disconnect_async()
 
+
