@@ -1,20 +1,37 @@
 from bergen.query import DelayedGQL
 
 
+INPUTS_FR = """
+  inputs {
+    __typename
+      key
+      required
+      description
+      widget {
+        __typename
+        dependencies
+        ... on QueryWidgetType {
+          query  
+        }
+      }
+      label
+      ... on ModelPortType {
+        identifier
+      }
+      ... on IntPortType {
+        default
+      }
+  }
+"""
+
+
 NODE_QUERY = DelayedGQL("""
 query Node($id: ID, $package: String, $interface: String){
   node(id: $id, package: $package, interface: $interface){
     id
     name
     image
-    inputs {
-      __typename
-      key
-      required
-      ... on ModelPortType {
-        identifier
-      }
-    }
+""" + INPUTS_FR + """
     outputs {
       __typename
       key
