@@ -70,6 +70,7 @@ class WebsocketPeasent(BasePeasent):
     async def configure(self):
         self.incoming_queue = asyncio.Queue()
         self.outgoing_queue = asyncio.Queue()
+        self.tasks = {}
         await self.startup()
         
     async def startup(self):
@@ -140,8 +141,23 @@ class WebsocketPeasent(BasePeasent):
         while True:
             message = await self.incoming_queue.get()
             message = AssignationMessage.from_channels(message)
-            assert message.data.pod is not None, "Received assignation that had no Pod?"
-            create_task(self.podid_function_map[message.data.pod](message)) # Run in parallel
+            if message.data.status == "CANCEL":
+                if message.data.reference in self.tasks: 
+                    logger.info("Cancellation for task received. Canceling!")
+                    task = self.tasks[message.data.reference]
+                    if not task.done():
+                        task.cancel()
+                        logger.warn("Canceled Task!!")
+                else:
+                    logger.error("Received Cancellation for task that was not in our tasks..")
+
+            else:  
+                assert message.data.pod is not None, "Received assignation that had no Pod?"
+                #
+                task = create_task(self.podid_function_map[message.data.pod](message))
+                self.tasks[message.data.reference] = task # Run in parallel
+
+
             self.incoming_queue.task_done()
 
 
