@@ -14,7 +14,7 @@ class BasePostman(ABC):
         pass
 
     @abstractmethod
-    def stream(inputs: dict, params: dict, **kwargs):
+    async def stream(inputs: dict, params: dict, **kwargs):
         return NotImplementedError( "Abstract class")
 
 
