@@ -6,12 +6,13 @@ from bergen.messages.provision import ProvisionMessage
 from bergen.messages.exceptions.base import ExceptionMessage
 from bergen.messages.types import ASSIGNATION, EXCEPTION, PROVISION
 from bergen.messages.base import MessageModel
-from bergen.messages.assignation_request import AssignationRequestMessage
+from bergen.messages.assignation_request import AssignationAction, AssignationRequestMessage
 from bergen.postmans.base import BasePostman
 from aiostream import stream
 import json
 import uuid
 import logging
+from functools import partial
 
 import asyncio
 try:
@@ -72,10 +73,13 @@ class WebsocketPostman(BasePostman):
     async def configure(self):
         self.callback_queue = asyncio.Queue()
         self.progress_queue = asyncio.Queue()
+        self.tasks = []
         self.startup_task = create_task(self.startup())
 
 
     async def disconnect(self):
+        for task in self.tasks:
+            task.cancel()
         if self.startup_task: self.startup_task.cancel()
         if self.consumer_task: self.consumer_task.cancel()
         if self.producer_task: self.producer_task.cancel()
@@ -108,7 +112,7 @@ class WebsocketPostman(BasePostman):
         )
 
         logger.error(f"Lost connection inbetween everything :( {[ task.exception() for task in done]}")
-        logger.error(f'Reconnecting to {self.url}')
+        logger.error(f'Reconnecting to {self.uri}')
 
         for task in pending:
             task.cancel()
@@ -306,11 +310,24 @@ class WebsocketPostman(BasePostman):
 
 
         await self.send_to_arnheim(request)
-            
+
+
+
+        future.add_done_callback(partial(self.check_if_cancelled, request))  
+
         outputs = await future
+
         return await expandOutputs(node_or_pod, outputs)
 
 
+    def check_if_cancelled(self, request: AssignationRequestMessage, future):
+        # We cancelled the future and now would like to cancel it also on the Arnheim side
+        if future.cancelled():
+            request.data.action = AssignationAction.CANCEL
+            self.tasks.append(asyncio.create_task(self.send_to_arnheim(request)))
+            print("hallo")
+
+
     async def provide(self, node, params, **extensions):
         correlation_id = str(uuid.uuid4()) # Where should we do this?
         future = self.loop.create_future()
