@@ -80,10 +80,20 @@ class Provider(ArnheimModel):
         identifier = "provider"
 
 
+class Widget(ArnheimObject):
+    query: Optional[str]
+    dependencies: Optional[List[str]]
+
+
 class Port(PortExtender, ArnheimObject):
+    __slots__ = ("_widget", )
+
     required: Optional[bool]
     key: Optional[str]
-    identifier: Optional[str] # Only for our friends the Models
+    identifier: Optional[str] 
+    label: Optional[str]
+    default: Optional[Any]
+    widget: Optional[Widget]
 
 
 class Node(ArnheimModel):
