@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
 from bergen.managers.base import BaseManager
-from bergen.types.manager import ModelManager
 from typing import Callable, Dict, Generic, List, Optional, TypeVar, Type
 from pydantic.fields import Field
 from pydantic.main import BaseModel, ModelMetaclass
@@ -32,7 +31,6 @@ class ArnheimModelManager(BaseManager, Generic[ModelType]):
             raise ArnheimModelConfigurationError(f"Make soure your Model {self.model.__name__}overwrites Meta identifier: {e}")
         from bergen.registries.arnheim import get_current_arnheim
 
-
         return get_current_arnheim().getWardForIdentifier(identifier=identifier)
 
     def _call_meta(self, attribute, ward=None, **kwargs):
@@ -184,6 +182,15 @@ class ArnheimModel(BaseModel, metaclass=ArnheimModelMeta):
     TYPENAME: str = Field(None, alias='__typename')
     id: Optional[int]
 
+    @classmethod
+    def get_ward(cls):
+        try:
+            identifier = cls.Meta.identifier
+        except Exception as e:
+            raise ArnheimModelConfigurationError(f"Make soure your Model {cls.__name__}overwrites Meta identifier: {e}")
+        from bergen.registries.arnheim import get_current_arnheim
+        return get_current_arnheim().getWardForIdentifier(identifier=identifier)
+
     @classmethod
     def getMeta(cls):
         return cls.Meta
